@@ -2,8 +2,7 @@ import os
 import click
 
 from energinetml.core.docker import build_prediction_api_docker_image
-
-from .utils import discover_model, discover_trained_model
+from energinetml.cli.utils import discover_model, discover_trained_model
 
 
 @click.command()
