@@ -28,6 +28,7 @@
     }
 
 """
+import json
 import logging
 from enum import Enum
 from typing import List, Any
@@ -229,7 +230,7 @@ class PredictionController(object):
         """
         self.logger.info('Prediction', extra={
             'custom_dimensions': {
-                'input': str(input.dict()),
-                'prediction': str(prediction),
+                'input': json.dumps(input.dict()),
+                'prediction': json.dumps(prediction),
             },
         })
